==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-modal-dialog/xl-react-widget-modal-dialog.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import {Modal} from 'react-bootstrap';
import classNames from 'classnames';

import {setTitleOnEllipsis} from '../../utils/tooltip';
import './xl-react-widget-modal-dialog.less';

export class XlReactWidgetModalDialog extends PureComponent {
    static propTypes = {
        animation: PropTypes.bool,
        children: PropTypes.oneOfType([PropTypes.object, PropTypes.array]),
        dialogClassName: PropTypes.string,
        expandable: PropTypes.bool,
        handleClose: PropTypes.func,
        showModal: PropTypes.bool,
        title: PropTypes.string
    };

    static defaultProps = {animation: false, expandable: false};

    constructor(props) {
        super(props);
        this.state = {expanded: false};
    }

    handleExpandClick = () => {
        this.setState({expanded: !this.state.expanded});
    };

    render() {
        const {
            animation,
            children,
            dialogClassName,
            expandable,
            handleClose,
            showModal = false,
            title
        } = this.props;

        const isCloseButtonAvailable = !R.isNil(handleClose);

        const handleMouseEnter = (event) => setTitleOnEllipsis($(event.currentTarget));
        const handleMouseOut = (event) => {
            event.currentTarget.title = '';
        };
        const {expanded} = this.state;
        const expandClassName = expanded ? 'condense-icon' : 'expand-icon';

        const modalTitle = () => title ? <Modal.Title>
            <span
                className="title"
                onMouseEnter={handleMouseEnter}
                onMouseOut={handleMouseOut}>
                {title}
                {expandable && <i className={expandClassName} onClick={this.handleExpandClick}/>}
            </span>
        </Modal.Title> : null;

        const modalHeader = <Modal.Header closeButton={isCloseButtonAvailable}>
            {modalTitle()}
        </Modal.Header>;

        const modalClassNames = classNames('xl-react-widget-modal-dialog', {'modal-expanded': expanded});

        return <div className={modalClassNames}>
            <div className="static-modal">
                <Modal
                    animation={animation}
                    bsClass={'xl-react-modal'}
                    className={modalClassNames}
                    dialogClassName={dialogClassName}
                    onHide={handleClose}
                    show={showModal}>
                    {modalHeader}
                    {children}
                </Modal>
            </div>
        </div>;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-modal-dialog/xl-react-widget-modal-dialog.js <==
import React, {PureComponent} from 'react';
import PropTypes from 'prop-types';
import R from 'ramda';
import {Modal} from 'react-bootstrap';
import classNames from 'classnames';

import {setTitleOnEllipsis} from '../../utils/tooltip';
import './xl-react-widget-modal-dialog.less';

export class XlReactWidgetModalDialog extends PureComponent {
    static propTypes = {
        animation: PropTypes.bool,
        children: PropTypes.oneOfType([PropTypes.object, PropTypes.array]),
        dialogClassName: PropTypes.string,
        expandable: PropTypes.bool,
        handleClose: PropTypes.func,
        showModal: PropTypes.bool,
        title: PropTypes.string
    };

    static defaultProps = {animation: false, expandable: false};

    constructor(props) {
        super(props);
        this.state = {expanded: false};
    }

    handleExpandClick = () => {
        this.setState({expanded: !this.state.expanded});
    };

    handleMouseEnter = (event) => setTitleOnEllipsis($(event.currentTarget));

    handleMouseOut = (event) => {
        event.currentTarget.title = '';
    };

    modalTitle = () => this.props.title ? <Modal.Title>
        <span
            className="title"
            onMouseEnter={this.handleMouseEnter}
            onMouseOut={this.handleMouseOut}>
            {this.props.title}
        </span>
    </Modal.Title> : null;

    closeButton = () => {
        const {expandable} = this.props;
        const {expanded} = this.state;
        const expandClassName = expanded ? 'condense-icon' : 'expand-icon';
        return expandable && <i className={expandClassName} onClick={this.handleExpandClick}/>;
    };

    render() {
        const {
            animation,
            children,
            dialogClassName,
            handleClose,
            showModal = false
        } = this.props;

        const {expanded} = this.state;

        const isCloseButtonAvailable = !R.isNil(this.props.handleClose);

        const modalHeader = <Modal.Header closeButton={isCloseButtonAvailable}>
            {this.closeButton()}
            {this.modalTitle()}
        </Modal.Header>;

        const modalClassNames = classNames('xl-react-widget-modal-dialog', {'modal-expanded': expanded});

        return <div className={modalClassNames}>
            <div className="static-modal">
                <Modal
                    animation={animation}
                    bsClass={'xl-react-modal'}
                    className={modalClassNames}
                    dialogClassName={dialogClassName}
                    onHide={handleClose}
                    show={showModal}>
                    {modalHeader}
                    {children}
                </Modal>
            </div>
        </div>;
    }
}
